{% extends "@SerenityAdmin/layout/base.html.twig" %}
{% block title %}
{% trans from "meta" %}Dashboard{% endtrans %}
{% endblock %}
{% block h2 %}Dashboard{% endblock %}
{% block main %}
<div class="h-full rounded-lg bg-white p-8 shadow-lg dark:bg-gray-800">
  <div class="relative"></div>
</div>
{% endblock %}
