<!-- Navbar -->
<nav
  {{
    attributes.defaults({
    class: 'fixed z-10 mt-0 flex flex-row flex-nowrap items-center justify-between px-6 py-2 shadow-sm transition-all duration-500 ease-in-out border-b border-gray-200 bg-white dark:border-gray-800 dark:bg-gray-900 start-0 end-0 md:start-64'
    })
  }}
  :class="{ 'start-64': open, '-end-64': open, 'md:start-0': open, 'md:end-0': open, 'start-0': !open, 'end-0': !open, 'md:start-64': !open }"
  id="desktop-menu">
  <!-- sidenav button -->
  <button
    id="navbartoggle"
    type="button"
    class="inline-flex items-center justify-center text-gray-800 hover:text-gray-600 focus:ring-0 focus:outline-none dark:text-gray-300 dark:hover:text-gray-200"
    aria-controls="sidebar-menu"
    @click="open = !open"
    aria-expanded="false"
    x-bind:aria-expanded="open.toString()">
    <span class="sr-only">Mobile menu</span>
    <svg
      x-description="Icon open"
      x-state:on="Menu open"
      x-state:off="Menu closed"
      class="hidden h-8 w-8"
      :class="{ 'block': open, 'hidden': !(open) }"
      xmlns="http://www.w3.org/2000/svg"
      fill="currentColor"
      viewBox="0 0 16 16">
      <path
          class="hidden md:block"
          fill-rule="evenodd"
          d="M2.5 12a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5z"
      />
      <path
          class="md:hidden"
          d="M2 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"
      />
    </svg>

    <svg
      x-description="Icon closed"
      x-state:on="Menu open"
      x-state:off="Menu closed"
      class="block h-8 w-8"
      :class="{ 'hidden': open, 'block': !(open) }"
      xmlns="http://www.w3.org/2000/svg"
      fill="currentColor"
      viewBox="0 0 16 16">
      <path
          class="md:hidden"
          fill-rule="evenodd"
          d="M2.5 12a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5z"
      />
      <path
          class="hidden md:block"
          d="M2 10.5a.5.5 0 0 1 .5-.5h3a.5.5 0 0 1 0 1h-3a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h7a.5.5 0 0 1 0 1h-7a.5.5 0 0 1-.5-.5zm0-3a.5.5 0 0 1 .5-.5h11a.5.5 0 0 1 0 1h-11a.5.5 0 0 1-.5-.5z"
      />
    </svg>
    <!-- <i class="fas fa-bars text-2xl"></i> -->
  </button>
  {% if config('admin',true) and config('admin',true).searchInput %}
    <!-- Search -->
    <form class="mx-5 hidden sm:inline-block md:hidden lg:inline-block">
      <div class="relative flex w-full flex-wrap items-stretch">
        <input
          type="text"
          class="relative max-w-full flex-shrink flex-grow overflow-x-auto border border-gray-100 bg-gray-100 px-4 py-2 text-sm leading-5 text-gray-800 focus:border-gray-200 focus:ring-0 focus:outline-none ltr:rounded-l rtl:rounded-r dark:border-gray-700 dark:bg-gray-700 dark:text-gray-400 dark:focus:border-gray-600"
          placeholder="Search…"
          aria-label="Search">
        <div class="-mr-px flex">
          <button
            class="border-primary bg-primary hover:border-primary-hover hover:bg-primary-hover focus:border-primary-hover focus:bg-primary-hover flex items-center border px-4 py-2 leading-5 text-gray-100 hover:text-white hover:ring-0 focus:ring-0 focus:outline-none ltr:-ml-1 ltr:rounded-r rtl:-mr-1 rtl:rounded-l"
            type="button">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              viewBox="0 0 24 24"
              fill="none"
              stroke="currentColor"
              stroke-width="2"
              stroke-linecap="round"
              stroke-linejoin="round"
              class="h-5 w-5">
              <circle cx="11" cy="11" r="8"></circle>
              <line x1="21" y1="21" x2="16.65" y2="16.65"></line>
            </svg>
            <!-- <i class="fas fa-search"></i> -->
          </button>
        </div>
      </div>
    </form>
  {% endif %}
  <!-- menu -->
  <ul class="flex min-h-12 ltr:ml-auto rtl:mr-auto">
    <!-- messages -->
    {#
    <li x-data="{ open: false }" class="relative">
      #} {#
      <a
        href="javascript:;"
        class="flex rounded-full px-4 py-3 text-sm focus:outline-none"
        id="messages"
        @click="open = ! open">
        #} {#
        <div class="relative inline-block">
          #} {#
          <svg
            xmlns="http://www.w3.org/2000/svg"
            fill="currentColor"
            class="bi bi-envelope h-6 w-6"
            viewBox="0 0 16 16">
            #}
            {# <path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V4zm2-1a1 1 0 0 0-1 1v.217l7 4.2 7-4.2V4a1 1 0 0 0-1-1H2zm13 2.383-4.758 2.855L15 11.114v-5.73zm-.034 6.878L9.271 8.82 8 9.583 6.728 8.82l-5.694 3.44A1 1 0 0 0 2 13h12a1 1 0 0 0 .966-.739zM1 11.114l4.758-2.876L1 5.383v5.73z"></path> #}
            {#
          </svg>
          #} {#
          <!-- <i class="fas fa-envelope text-2xl"></i> -->
          #} {#
          <span class="absolute -top-2 flex justify-center rounded-full bg-pink-500 px-1 text-center text-xs text-white ltr:-right-1 rtl:-left-1"
            ><span class="align-self-center">3</span></span
          >
          #} {#
        </div>
        #} {#
      </a>
      #}

      {#
      <div
        x-show="open"
        @click.away="open = false"
        x-transition:enter="transition-all duration-200 ease-out"
        x-transition:enter-start="transform opacity-0 scale-95"
        x-transition:enter-end="transform opacity-100 scale-100"
        x-transition:leave="transition-all duration-200 ease-in"
        x-transition:leave-start="transform opacity-100 scale-100"
        x-transition:leave-end="transform opacity-0 scale-95"
        class="absolute top-full z-50 w-72 origin-top-right rounded border bg-white py-0.5 shadow-md ltr:-right-36 ltr:text-left md:ltr:right-0 rtl:-left-36 rtl:text-right md:rtl:left-0 dark:border-gray-700 dark:bg-gray-800"
        style="display: none;">
        #} {#
        <div class="border-b border-gray-200 p-3 font-normal dark:border-gray-700">
          #} {#
          <div class="relative">
            #} {#
            <div class="font-bold">Messages</div>
            #} {#
            <div x-data="{ open: false }" class="absolute top-0 ltr:right-0 rtl:left-0">
              #} {#
              <a
                @click="open = ! open"
                href="javascript:;"
                class="inline-block ltr:mr-2 rtl:ml-2"
                title="Search message">
                #} {#
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  fill="currentColor"
                  class="bi bi-search inline-block h-4 w-4"
                  viewBox="0 0 16 16">
                  #}
                  {# <path d="M11.742 10.344a6.5 6.5 0 1 0-1.397 1.398h-.001c.03.04.062.078.098.115l3.85 3.85a1 1 0 0 0 1.415-1.414l-3.85-3.85a1.007 1.007 0 0 0-.115-.1zM12 6.5a5.5 5.5 0 1 1-11 0 5.5 5.5 0 0 1 11 0z"/> #}
                  {#
                </svg>
                #} {#
                <!-- <i class="fas fa-search"></i> -->
                #} {#
              </a>
              #} {#
              <div
                x-show="open"
                @click.away="open = false"
                class="absolute z-10 origin-top-right rounded bg-white ltr:right-0 rtl:left-0 dark:bg-gray-700"
                style="min-width:16rem">
                #} {#
                <form class="inline-block w-full">
                  #} {#
                  <div class="relative flex w-full flex-wrap items-stretch">
                    #} {#
                    <input
                      type="text"
                      class="relative max-w-full flex-shrink flex-grow overflow-x-auto border border-gray-100 bg-gray-100 px-4 py-2 text-sm leading-5 text-gray-800 focus:border-gray-200 focus:ring-0 focus:outline-none ltr:rounded-l rtl:rounded-r dark:border-gray-700 dark:bg-gray-700 dark:text-gray-400 dark:focus:border-gray-600"
                      placeholder="Search messages…"
                      aria-label="Search">
                    #} {#
                    <div class="-mr-px flex">
                      #} {#
                      <button
                        class="border-primary bg-primary hover:border-primary-hover hover:bg-primary-hover focus:border-primary-hover focus:bg-primary-hover flex items-center border px-4 py-2 leading-5 text-gray-100 hover:text-white hover:ring-0 focus:ring-0 focus:outline-none ltr:-ml-1 ltr:rounded-r rtl:-mr-1 rtl:rounded-l"
                        type="button">
                        #} {#
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          stroke-width="2"
                          stroke-linecap="round"
                          stroke-linejoin="round"
                          class="h-5 w-5">
                          <circle cx="11" cy="11" r="8"></circle><line x1="21" y1="21" x2="16.65" y2="16.65"></line>
                        </svg>
                        #} {#
                        <!-- <i class="fas fa-search"></i> -->
                        #} {#
                      </button>
                      #} {#
                    </div>
                    #} {#
                  </div>
                  #} {#
                </form>
                #} {#
              </div>
              #} {#
              <a href="#" class="inline-block ltr:mr-2 rtl:ml-2" title="Mark all as read">
                #} {#
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  fill="currentColor"
                  class="bi bi-envelope-open inline-block h-4 w-4"
                  viewBox="0 0 16 16">
                  #}
                  {# <path d="M8.47 1.318a1 1 0 0 0-.94 0l-6 3.2A1 1 0 0 0 1 5.4v.818l5.724 3.465L8 8.917l1.276.766L15 6.218V5.4a1 1 0 0 0-.53-.882l-6-3.2zM15 7.388l-4.754 2.877L15 13.117v-5.73zm-.035 6.874L8 10.083l-6.965 4.18A1 1 0 0 0 2 15h12a1 1 0 0 0 .965-.738zM1 13.117l4.754-2.852L1 7.387v5.73zM7.059.435a2 2 0 0 1 1.882 0l6 3.2A2 2 0 0 1 16 5.4V14a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V5.4a2 2 0 0 1 1.059-1.765l6-3.2z"/> #}
                  {#
                </svg>
                #} {#
                <!-- <i class="fas fa-envelope-open"></i> -->
                #} {#
              </a>
              #} {#
              <a href="#" class="inline-block ltr:mr-2 rtl:ml-2" title="New message">
                #} {#
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  fill="currentColor"
                  class="bi bi-pencil-square inline-block h-4 w-4"
                  viewBox="0 0 16 16">
                  #}
                  {# <path d="M15.502 1.94a.5.5 0 0 1 0 .706L14.459 3.69l-2-2L13.502.646a.5.5 0 0 1 .707 0l1.293 1.293zm-1.75 2.456-2-2L4.939 9.21a.5.5 0 0 0-.121.196l-.805 2.414a.25.25 0 0 0 .316.316l2.414-.805a.5.5 0 0 0 .196-.12l6.813-6.814z"/> #}
                  {# <path fill-rule="evenodd" d="M1 13.5A1.5 1.5 0 0 0 2.5 15h11a1.5 1.5 0 0 0 1.5-1.5v-6a.5.5 0 0 0-1 0v6a.5.5 0 0 1-.5.5h-11a.5.5 0 0 1-.5-.5v-11a.5.5 0 0 1 .5-.5H9a.5.5 0 0 0 0-1H2.5A1.5 1.5 0 0 0 1 2.5v11z"/> #}
                  {#
                </svg>
                #} {#
                <!-- <i class="fas fa-edit"></i> -->
                #} {#
              </a>
              #} {#
            </div>
            #} {#
          </div>
          #} {#
        </div>
        #} {#
        <div class="scrollbars show max-h-60 overflow-y-auto">
          #} {#
          <a href="#">
            #} {#
            <div class="dark:bg-opacity-40 dark:hover:bg-opacity-20 flex flex-row flex-wrap items-center border-b border-gray-200 bg-gray-50 py-2 hover:bg-gray-100 dark:border-gray-700 dark:bg-gray-900">
              #} {#
              <div class="w-1/4 max-w-full flex-shrink px-2 text-center">
                #} {#
                <div class="relative">
                  #} {#
                  <img src="src/img/avatar/avatar2.png" class="mx-auto h-10 w-10 rounded-full" alt="Daniel Esteban"> #}
                  {#
                  <span
                    title="online"
                    class="absolute -bottom-0.5 flex h-3 w-3 justify-center rounded-full border border-white bg-green-500 text-center ltr:right-2 rtl:left-2"></span>
                  #} {#
                </div>
                #} {#
              </div>
              #} {#
              <div class="w-3/4 max-w-full flex-shrink px-2">
                #} {#
                <div class="text-sm font-bold">Daniel Esteban</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">What do you think about this project?</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">12m ago</div>
                #} {#
              </div>
              #} {#
            </div>
            #} {#
          </a>
          #} {#
          <a href="#">
            #} {#
            <div class="dark:bg-opacity-40 dark:hover:bg-opacity-20 flex flex-row flex-wrap items-center border-b border-gray-200 bg-gray-50 py-2 hover:bg-gray-100 dark:border-gray-700 dark:bg-gray-900">
              #} {#
              <div class="w-1/4 max-w-full flex-shrink px-2 text-center">
                #} {#
                <div class="relative">
                  #} {#
                  <img src="src/img/avatar/avatar3.png" class="mx-auto h-10 w-10 rounded-full" alt="Carlos Garcia"> #}
                  {#
                  <span
                    title="busy"
                    class="absolute -bottom-0.5 flex h-3 w-3 justify-center rounded-full border border-white bg-pink-500 text-center ltr:right-2 rtl:left-2"></span>
                  #} {#
                </div>
                #} {#
              </div>
              #} {#
              <div class="w-3/4 max-w-full flex-shrink px-2">
                #} {#
                <div class="text-sm font-bold">Carlos Garcia</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">Hello, how are you friends?</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">30m ago</div>
                #} {#
              </div>
              #} {#
            </div>
            #} {#
          </a>
          #} {#
          <a href="#">
            #} {#
            <div class="dark:bg-opacity-40 dark:hover:bg-opacity-20 flex flex-row flex-wrap items-center border-b border-gray-200 bg-gray-50 py-2 hover:bg-gray-100 dark:border-gray-700 dark:bg-gray-900">
              #} {#
              <div class="w-1/4 max-w-full flex-shrink px-2 text-center">
                #} {#
                <div class="relative">
                  #} {#
                  <img src="src/img/avatar/avatar4.png" class="mx-auto h-10 w-10 rounded-full" alt="Steven Rey"> #} {#
                  <span
                    title="offline"
                    class="absolute -bottom-0.5 flex h-3 w-3 justify-center rounded-full border border-white bg-gray-500 text-center ltr:right-2 rtl:left-2"></span>
                  #} {#
                </div>
                #} {#
              </div>
              #} {#
              <div class="w-3/4 max-w-full flex-shrink px-2">
                #} {#
                <div class="text-sm font-bold">Steven Rey</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">Thank you for your help today.</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">4h ago</div>
                #} {#
              </div>
              #} {#
            </div>
            #} {#
          </a>
          #} {#
          <a href="#">
            #} {#
            <div class="dark:hover:bg-opacity-20 flex flex-row flex-wrap items-center border-b border-gray-200 py-2 hover:bg-gray-100 dark:border-gray-700 dark:hover:bg-gray-900">
              #} {#
              <div class="w-1/4 max-w-full flex-shrink px-2 text-center">
                #} {#
                <div class="relative">
                  #} {#
                  <img src="src/img/avatar/avatar.png" class="mx-auto h-10 w-10 rounded-full" alt="Roman Davis"> #} {#
                  <span
                    title="offline"
                    class="absolute -bottom-0.5 flex h-3 w-3 justify-center rounded-full border border-white bg-gray-500 text-center ltr:right-2 rtl:left-2"></span>
                  #} {#
                </div>
                #} {#
              </div>
              #} {#
              <div class="w-3/4 max-w-full flex-shrink px-2">
                #} {#
                <div class="text-sm font-bold">Roman Davis</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">Do you have time? I want to call you.</div>
                #} {#
                <div class="mt-1 text-sm text-gray-500">5h ago</div>
                #} {#
              </div>
              #} {#
            </div>
            #} {#
          </a>
          #} {#
        </div>
        #} {#
        <div class="p-3 text-center font-normal">
          #} {# <a href="#" class="hover:underline">Show all Messages</a> #} {#
        </div>
        #} {#
      </div>
      #} {#
    </li>
    #}
    {% if config('admin',true) and config('admin',true).notificationPanel %}
      <!-- notification -->
      <li x-data="{ open: false }" class="relative">
        <a
          href="javascript:;"
          class="flex rounded-full px-4 py-3 text-sm focus:outline-none"
          id="notify"
          @click="open = ! open">
          <div class="relative inline-block">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              fill="currentColor"
              class="bi bi-bell h-6 w-6"
              viewBox="0 0 16 16">
              <path
                  d="M8 16a2 2 0 0 0 2-2H6a2 2 0 0 0 2 2zM8 1.918l-.797.161A4.002 4.002 0 0 0 4 6c0 .628-.134 2.197-.459 3.742-.16.767-.376 1.566-.663 2.258h10.244c-.287-.692-.502-1.49-.663-2.258C12.134 8.197 12 6.628 12 6a4.002 4.002 0 0 0-3.203-3.92L8 1.917zM14.22 12c.223.447.481.801.78 1H1c.299-.199.557-.553.78-1C2.68 10.2 3 6.88 3 6c0-2.42 1.72-4.44 4.005-4.901a1 1 0 1 1 1.99 0A5.002 5.002 0 0 1 13 6c0 .88.32 4.2 1.22 6z"
              />
            </svg>
            <!-- <i class="fas fa-bell text-2xl"></i> -->
            <span
              class="bg-primary absolute -top-2 flex justify-center rounded-full px-1 text-center text-xs text-white ltr:-right-1 rtl:-left-1">
              <span class="align-self-center">1</span>
            </span>
          </div>
        </a>

        <div
          x-show="open"
          x-on:click.away="open = false"
          x-transition:enter="transition-all duration-200 ease-out"
          x-transition:enter-start="transform opacity-0 scale-95"
          x-transition:enter-end="transform opacity-100 scale-100"
          x-transition:leave="transition-all duration-200 ease-in"
          x-transition:leave-start="transform opacity-100 scale-100"
          x-transition:leave-end="transform opacity-0 scale-95"
          class="absolute top-full z-50 w-72 origin-top-right rounded border bg-white py-0.5 shadow-md ltr:right-0 ltr:text-left rtl:left-0 rtl:text-right dark:border-gray-700 dark:bg-gray-800"
          style="display: none;">
          <div class="border-b border-gray-200 p-3 font-normal dark:border-gray-700">
            <div class="relative">
              <div class="font-bold">Notifications</div>
              <div class="absolute top-0 ltr:right-0 rtl:left-0">
                <a href="#" class="inline-block ltr:mr-2 rtl:ml-2" title="Clear all">
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    fill="currentColor"
                    class="bi bi-trash inline-block h-4 w-4"
                    viewBox="0 0 16 16">
                    <path
                        d="M5.5 5.5A.5.5 0 0 1 6 6v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm2.5 0a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5zm3 .5a.5.5 0 0 0-1 0v6a.5.5 0 0 0 1 0V6z"
                    />
                    <path
                        fill-rule="evenodd"
                        d="M14.5 3a1 1 0 0 1-1 1H13v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V4h-.5a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1H6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1h3.5a1 1 0 0 1 1 1v1zM4.118 4 4 4.059V13a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V4.059L11.882 4H4.118zM2.5 3V2h11v1h-11z"
                    />
                  </svg>
                  <!-- <i class="fas fa-trash-alt"></i> -->
                </a>
              </div>
            </div>
          </div>
          <div class="scrollbars show max-h-60 overflow-y-auto">
            <a class="relative" href="#">
              <div
                class="dark:bg-opacity-40 dark:hover:bg-opacity-20 flex flex-row flex-wrap items-center border-b border-gray-200 bg-gray-50 py-2 hover:bg-gray-100 dark:border-gray-700 dark:bg-gray-900">
                <div class="w-1/4 max-w-full flex-shrink px-2 text-center">
                  <div class="bg-primary mx-auto flex h-8 w-8 justify-center rounded-full text-white">
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      fill="currentColor"
                      class="bi bi-calendar4-event h-4 w-4 self-center"
                      viewBox="0 0 16 16">
                      <path
                          d="M3.5 0a.5.5 0 0 1 .5.5V1h8V.5a.5.5 0 0 1 1 0V1h1a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2V3a2 2 0 0 1 2-2h1V.5a.5.5 0 0 1 .5-.5zM2 2a1 1 0 0 0-1 1v1h14V3a1 1 0 0 0-1-1H2zm13 3H1v9a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V5z"
                      />
                      <path
                          d="M11 7.5a.5.5 0 0 1 .5-.5h1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-1a.5.5 0 0 1-.5-.5v-1z"/>
                    </svg>
                    <!-- <i class="fas fa-calendar self-center"></i> -->
                  </div>
                </div>
                <div class="w-3/4 max-w-full flex-shrink px-2">
                  <div class="text-sm font-bold">Nouveau produit ajouté</div>
                  <div class="mt-1 text-sm text-gray-500">Ratafia Champenois IGP</div>
                  <div class="mt-1 text-sm text-gray-500">Il y a 1h</div>
                </div>
              </div>
            </a>
          </div>
          <div class="p-3 text-center font-normal">
            <a href="#" class="hover:underline">Voir toutes les notifications</a>
          </div>
        </div>
      </li>
    {% endif %}
    <twig:SerenityAdmin:Menu:Navbar:Profile />
  </ul>
</nav>
<!-- End Navbar -->
