@theme {
  --font-sans: "Switzer", ui-sans-serif, system-ui, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  --font-display: "Switzer", "sans-serif";
}

@font-face {
  font-family: 'Switzer';
  src: url('../../fonts/Switzer-Variable.woff2') format('woff2'),
  url('../../fonts/Switzer-Variable.woff') format('woff'),
  url('../../fonts/Switzer-Variable.ttf') format('truetype');
  font-weight: 100 900;
  font-display: swap;
  font-style: normal;
}


@font-face {
  font-family: 'Switzer';
  src: url('../../fonts/Switzer-VariableItalic.woff2') format('woff2'),
  url('../../fonts/Switzer-VariableItalic.woff') format('woff'),
  url('../../fonts/Switzer-VariableItalic.ttf') format('truetype');
  font-weight: 100 900;
  font-display: swap;
  font-style: italic;
}
