<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Serenity\AdminBundle\EventListener;

use Serenity\AdminBundle\Event\ParamsAdminMenuEvent;
use Symfony\Component\EventDispatcher\Attribute\AsEventListener;

#[AsEventListener()]
readonly class ParamsAdminMenuListener
{
    public function __construct()
    {
    }

    public function __invoke(ParamsAdminMenuEvent $event): void
    {
        $menu = $event->getMenu();
    }
}
