@layer utilities {
  .table-striped {
    @apply [&>tr:nth-child(odd)]:bg-white
    [&>tr:nth-child(even)]:bg-gray-100
    dark:[&>tr:nth-child(odd)]:bg-gray-800
    dark:[&>tr:nth-child(even)]:bg-gray-700;
  }
}
